#!/bin/bash

# INSTALL qt-opensource-x86-5.9.2.exe to c:/src/Qt

set -e

V=5.9.2
B=3

D="$(cd $(dirname "$0") && pwd )"

rm -f $D/package.log.9
for i in $(seq 8 -1 1); do
	[ -f $D/package.log.$i ] && mv $D/package.log.$i $D/package.log.$(( i + 1 ))
done
[ -f $D/package.log ] && mv $D/package.log $D/package.log.1

exec > >(tee package.log) 2>&1

set -x

OSGEO4W_REP=/tmp/rep

if [ -d /c/src/Qt ]; then
	mv /c/src/Qt /c/src/Qt.off
fi

for i in 32 64; do
	case $i in
	32)
		export O4W=/tmp/OSGeo4W
		export QTB=msvc2015
		export A=x86
		;;
	64)
		export O4W=/tmp/OSGeo4W64
		export QTB=msvc2015_64
		export A=x86_64
		;;
	*)
		false
		;;
	esac

	cd /c/src/Qt.off

	rm -rf $O4W
	mkdir -p $O4W/bin $O4W/etc/postinstall $O4W/apps/Qt5

	cp $D/qt5_env.bat $O4W/bin
	cp $D/qt5-libs-postinstall.bat $O4W/etc/postinstall/qt5-libs.bat
	cp $D/qt5.conf.tmpl $O4W/bin

	[ -d "Qt$V/$V/$QTB" ]

	tar -C Qt$V  \
		--exclude $V/msvc2015 \
		--exclude $V/msvc2015_64 \
		--exclude Tools/QtCreator \
		--exclude Examples \
		--exclude vcredist \
		--exclude qtenv2.bat \
		--exclude qt.conf \
		-cf - . | tar -C $O4W/apps/Qt5 -xf -

	tar -C Qt$V/$V/$QTB \
		--exclude "bin/QtWebEngineProcessd.*" \
		-cf - . | tar -C $O4W/apps/Qt5 -xf -

	#
	#
	#

	cd $O4W


        find apps/Qt5 -name "*d.dll" | while read f
        do
		if ! [ -f "${f%d.dll}.dll" ]; then
			continue
		fi

		echo $f

                f=${f/\/bin\//\/lib\/}
		f=${f%.dll}

                ! [ -f "$f.prl" ] || echo $f.prl
                ! [ -f "$f.lib" ] || echo $f.lib
        done >/tmp/debuglibs-$A

	QT5REP=$OSGEO4W_REP/$A/release/qt5

	for i in libs-debug devel doc qml libs tools; do
		mkdir -p $QT5REP/qt5-$i
	done

	cat <<EOF >$QT5REP/qt5-libs-debug/setup.hint
sdesc: "Qt5 runtime libraries (debug version)"
ldesc: "Qt5 runtime libraries (debug version)"
maintainer: JuergenFischer
category: Libs
requires: shell zlib
external-source: qt5-libs
EOF
	tar -cjvf $QT5REP/qt5-libs-debug/qt5-libs-debug-$V-$B.tar.bz2 --remove-files \
		-T /tmp/debuglibs-$A \
		>$QT5REP/qt5-libs-debug/qt5-libs-debug.manifest

	cat <<EOF >$QT5REP/qt5-tools/setup.hint
sdesc: "Qt5 designer & linguist (Development)"
ldesc: "Qt5 designer & linguist (Development)"
maintainer: JuergenFischer
category: Libs
requires: shell qt5-libs
external-source: qt5-libs
EOF
	tar -cjvf $QT5REP/qt5-tools/qt5-tools-$V-$B.tar.bz2 --remove-files \
		apps/Qt5/translations/linguist_*.qm \
		apps/Qt5/translations/designer_*.qm \
		apps/Qt5/bin/designer.exe \
		apps/Qt5/bin/linguist.exe \
		>$QT5REP/qt5-tools/qt5-tools.manifest

	cat <<EOF >$QT5REP/qt5-devel/setup.hint
sdesc: "Qt5 headers and libraries (Development)"
ldesc: "Qt5 headers and libraries (Development)"
maintainer: JuergenFischer
category: Libs
requires: shell qt5-libs
external-source: qt5-libs
EOF
	tar -cjvf $QT5REP/qt5-devel/qt5-devel-$V-$B.tar.bz2 --remove-files \
		apps/Qt5/include \
		apps/Qt5/mkspecs \
		apps/Qt5/phrasebooks \
		apps/Qt5/lib \
		apps/Qt5/translations/assistant_*.qm \
		apps/Qt5/translations/qmlviewer_*.qm \
		apps/Qt5/bin/*.exe \
		>$QT5REP/qt5-devel/qt5-devel.manifest

	cat <<EOF >$QT5REP/qt5-doc/setup.hint
sdesc: "Qt5 documentation (Development)"
ldesc: "Qt5 documentation (Development)"
maintainer: JuergenFischer
category: Libs
external-source: qt5-libs
EOF
	tar -cjvf $QT5REP/qt5-doc/qt5-doc-$V-$B.tar.bz2 --remove-files \
		apps/qt5/doc \
		apps/qt5/Docs \
		>$QT5REP/qt5-doc/qt5-doc.manifest

	cat <<EOF >$QT5REP/qt5-qml/setup.hint
sdesc: "Qt5 QML"
ldesc: "Qt5 QML"
maintainer: JuergenFischer
category: Libs
external-source: qt5-libs
EOF
	tar -cjvf $QT5REP/qt5-qml/qt5-qml-$V-$B.tar.bz2 --remove-files \
		apps/qt5/qml \
		>$QT5REP/qt5-qml/qt5-qml.manifest

	cat <<EOF >$QT5REP/qt5-libs/setup.hint
sdesc: "Qt5 runtime libraries"
ldesc: "Qt5 runtime libraries"
maintainer: JuergenFischer
category: Libs
requires: shell zlib openssl sqlite3 msvcrt2015
EOF
	tar -cjvf $QT5REP/qt5-libs/qt5-libs-$V-$B.tar.bz2 --remove-files \
		apps/Qt5 \
		bin/qt5_env.bat \
		bin/qt5.conf.tmpl \
		etc/postinstall/qt5-libs.bat \
		>$QT5REP/qt5-libs/qt5-libs.manifest

	tar -C $D/.. -cjvf $QT5REP/qt5-libs/qt5-libs-$V-$B-src.tar.bz2 \
		osgeo4w/qt5_env.bat \
		osgeo4w/qt5-libs-postinstall.bat \
		osgeo4w/qt5.conf.tmpl \
		osgeo4w/package-qt5.sh

	echo -n "Remaining files:"
	find -type f
done

exit ### END
